package com.benyun.project.third.material.mapper;


import com.benyun.project.third.material.domain.ByMaterialOut;

import java.util.List;

/**
 * 犇云物料内外对应Mapper接口
 * 
 * @author benyun
 * @date 2023-12-04
 */
public interface ByMaterialOutMapper 
{
    /**
     * 查询犇云物料内外对应
     * 
     * @param id 犇云物料内外对应主键
     * @return 犇云物料内外对应
     */
    public ByMaterialOut selectByMaterialOutById(Long id);

    /**
     * 查询犇云物料内外对应列表
     * 
     * @param byMaterialOut 犇云物料内外对应
     * @return 犇云物料内外对应集合
     */
    public List<ByMaterialOut> selectByMaterialOutList(ByMaterialOut byMaterialOut);

    /**
     * 新增犇云物料内外对应
     * 
     * @param byMaterialOut 犇云物料内外对应
     * @return 结果
     */
    public int insertByMaterialOut(ByMaterialOut byMaterialOut);

    /**
     * 修改犇云物料内外对应
     * 
     * @param byMaterialOut 犇云物料内外对应
     * @return 结果
     */
    public int updateByMaterialOut(ByMaterialOut byMaterialOut);

    /**
     * 删除犇云物料内外对应
     * 
     * @param id 犇云物料内外对应主键
     * @return 结果
     */
    public int deleteByMaterialOutById(Long id);

    /**
     * 批量删除犇云物料内外对应
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteByMaterialOutByIds(String[] ids);

    public int batchSaveMaterialList(List<ByMaterialOut> materialList);

    public ByMaterialOut selectByMaterialOutByCode(String code);

    //根据外部物料ID查询
    public ByMaterialOut selectByMaterialOutByOutId(String outMaterialId);
}
